@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: trifecta
 version: 1.5.2
-id: trifecta-1.5.2-bd36f790bdcdc22a803fc370fcbeed79
-key: trife_1YbJwKd4k390V1NoauC6LO
+id: trifecta-1.5.2-eb1dd4d699e260a8c6e1c779cdeab2db
+key: trife_0DA5J1lYbp54emHKjJmcMH
 license: BSD3
 copyright: Copyright (C) 2010-2014 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,7 +27,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/trifecta-1.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/trifecta-1.5.2
-hs-libraries: HStrifecta-1.5.2-1YbJwKd4k390V1NoauC6LO
+hs-libraries: HStrifecta-1.5.2-0DA5J1lYbp54emHKjJmcMH
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
@@ -38,17 +38,17 @@ depends:
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     charset-0.3.7.1-543137c1a84e9708652346da73519711
-    comonad-5-caa084d849f0fd836e529854caff7fc2
+    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    lens-4.13.1-6a5b95f92a8423d4381fcfe97443e936
+    lens-4.13.1-0500c41dd5bf4a913992f535a881c76b
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    parsers-0.12.3-c0d901a3a61df7aba5c3c4c58e408834
-    profunctors-5.2-69458fa119e6a2dfd209808104f4439d
-    reducers-3.12.1-b47bfdc7f0a6659f9bf2fd0e08e03bf7
+    parsers-0.12.3-e9ff529474e9ade28ca7d7edafd220d1
+    profunctors-5.2-9bddc68ddf0f4fcea803005a53816983
+    reducers-3.12.1-ea06090a8c66812eff0cd7d6cba6d6c9
     semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
